Who Is Using It? — sphinx-notfound-page 0.4 documentation

# Who Is Using It?

These are some projects using this extension that you can take a look at to understand how they are configured and what’s the behavior.

## Read the Docs

- https://github.com/readthedocs/readthedocs.org
- Example URL
- Configuration file

## PyVista

- https://github.com/pyvista/pyvista
- Example URL
- Configuration file

## Write the Docs

- https://github.com/writethedocs/www
- Example URL
- Configuration file

## The Carpentries

- https://github.com/carpentries/handbook
- Example URL
- Configuration file

← Get Involved Frequently Asked Questions →